<?php

namespace Litepci\Probation\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Probation\Models\Probation;

class ProbationPolicy
{

    /**
     * Determine if the given user can view the probation.
     *
     * @param UserPolicy $user
     * @param Probation $probation
     *
     * @return bool
     */
    public function view(UserPolicy $user, Probation $probation)
    {
        if ($user->canDo('probation.probation.view') && $user->isAdmin()) {
            return true;
        }

        return $probation->user_id == user_id() && $probation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a probation.
     *
     * @param UserPolicy $user
     * @param Probation $probation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('probation.probation.create');
    }

    /**
     * Determine if the given user can update the given probation.
     *
     * @param UserPolicy $user
     * @param Probation $probation
     *
     * @return bool
     */
    public function update(UserPolicy $user, Probation $probation)
    {
        if ($user->canDo('probation.probation.edit') && $user->isAdmin()) {
            return true;
        }

        return $probation->user_id == user_id() && $probation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given probation.
     *
     * @param UserPolicy $user
     * @param Probation $probation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Probation $probation)
    {
        return $probation->user_id == user_id() && $probation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given probation.
     *
     * @param UserPolicy $user
     * @param Probation $probation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Probation $probation)
    {
        if ($user->canDo('probation.probation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given probation.
     *
     * @param UserPolicy $user
     * @param Probation $probation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Probation $probation)
    {
        if ($user->canDo('probation.probation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
